"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useBalances = void 0;
const react_1 = require("react");
const contexts_1 = require("../contexts");
const objects_1 = require("../interfaces/objects");
var EActionTypes;
(function (EActionTypes) {
    EActionTypes["FETCHING"] = "FETCHING";
    EActionTypes["FETCHED"] = "FETCHED";
    EActionTypes["ERROR"] = "ERROR";
})(EActionTypes || (EActionTypes = {}));
function useBalances() {
    const { proxy } = react_1.useContext(contexts_1.StoreContext);
    const initialState = {
        loading: true,
        error: null,
        balances: [],
    };
    const [state, dispatch] = react_1.useReducer((state, action) => {
        switch (action.type) {
            case EActionTypes.FETCHING:
                return Object.assign(Object.assign({}, state), { loading: true });
            case EActionTypes.FETCHED:
                return Object.assign(Object.assign({}, state), { loading: false, balances: action.payload });
            case EActionTypes.ERROR:
                return Object.assign(Object.assign({}, state), { loading: false, error: action.payload });
            default:
                return state;
        }
    }, initialState);
    react_1.useEffect(() => {
        let cancelRequest = false;
        const fetchData = () => __awaiter(this, void 0, void 0, function* () {
            dispatch({ type: EActionTypes.FETCHING });
            try {
                if (cancelRequest)
                    return;
                // get data from proxy
                proxy === null || proxy === void 0 ? void 0 : proxy.getBalances().map((balance) => {
                    // prepare balances
                    dispatch({
                        type: EActionTypes.FETCHED,
                        payload: prepareBalances(balance),
                    });
                });
            }
            catch (error) {
                if (cancelRequest)
                    return;
                dispatch({ type: EActionTypes.ERROR, payload: error.message });
            }
        });
        fetchData();
        proxy === null || proxy === void 0 ? void 0 : proxy.onBalancesChanged.subscribe({
            next: (balance) => {
                if (cancelRequest)
                    return;
                dispatch({
                    type: EActionTypes.FETCHED,
                    payload: prepareBalances(balance),
                });
            },
        });
        return function cleanup() {
            cancelRequest = true;
        };
    }, []);
    const prepareBalances = (balance) => {
        return balance.assets.reduce((acc, assetBalance) => {
            acc.push(new objects_1.AssetBalanceViewModel(new objects_1.AssetBalanceParams(assetBalance)));
            return acc;
        }, []);
    };
    return state;
}
exports.useBalances = useBalances;
//# sourceMappingURL=useBalances.js.map